| Model Thinking

Skip Navigation
This page features MathJax technology to render mathematical formulae. If you are using a screen reader, please visit MathPlayer to download the plugin for your browser. Please note that this is an Internet Explorer-only plugin at this time.

# Model Thinking

## Top Navigation Bar

Jobs Team Contact Us About Us
Courses Profile Course Records Settings Course Preferences Logout
Model Thinking
Scott E Page
February 2012

## Video Lectures

Having trouble viewing lectures? Try changing your player in course preferences.

### Introduction: Why Model?

(expanded, click to collapse)

- Why Model?
- Intelligent Citizens of the World
- Thinking More Clearly
- Using and Understanding Data
- Using Models to Decide, Strategize, and Design

### Segregation and Peer Effects

(expanded, click to collapse)

- Sorting and Peer Effects Introduction
- Schelling's Segregation Model
- Measuring Segregation
- Peer Effects
- The Standing Ovation Model
- The Identification Problem

### Aggregation

(expanded, click to collapse)

- Aggregation
- Central Limit Theorem
- Six Sigma
- Game of Life
- Cellular Automata
- Preference Aggregation

### Decision Models

(expanded, click to collapse)

- Introduction to Decision Making
- Multi-Criterion Decision Making
- Spatial Choice Models
- Probability: The Basics
- Decision Trees
- Value of Information

### Thinking Electrons: Modeling People

(expanded, click to collapse)

- Thinking Electrons: Modeling People
- Rational Actor Models
- Behavioral Models
- Rule Based Models
- When Does Behavior Matter?

### Categorical and Linear Models

(expanded, click to collapse)

- Introduction to Linear Models
- Categorical Models
- Linear Models
- Fitting Lines to Data
- Reading Regression Output
- From Linear to Nonlinear
- The Big Coefficient vs The New Reality

### Tipping Points

(expanded, click to collapse)

- Tipping Points
- Percolation Models
- Contagion Models 1: Diffusion
- Contagion Models 2: SIS Model
- Classifying Tipping Points
- Measuring Tips

### Economic Growth

(expanded, click to collapse)

- Introduction To Growth
- Exponential Growth
- Basic Growth Model
- Solow Growth Model
- WIll China Continue to Grow?
- Why Do Some Countries Not Grow?

### Diversity and Innovation

(expanded, click to collapse)

- Problem Solving and Innovation
- Perspectives and Innovation
- Heuristics
- Teams and Problem Solving
- Recombination

### Markov Processes

(expanded, click to collapse)

- Markov Models
- A Simple Markov Model
- Markov Model of Democratization
- Markov Convergence Theorem
- Exapting the Markov Model

### Lyapunov Functions

(expanded, click to collapse)

- Lyapunov Functions
- The Organization of Cities
- Exchange Economies and Externalities
- Time to Convergence and Optimality
- Lyapunov: Fun and Deep
- Lyapunov or Markov

### Coordination and Culture

(expanded, click to collapse)

- Coordination and Culture
- What Is Culture And Why Do We Care?
- Pure Coordination Game
- Emergence of Culture
- Coordination and Consistency

### Path Dependence

(expanded, click to collapse)

- Path Dependence
- Urn Models
- Mathematics on Urn Models
- Path Dependence and Chaos
- Path Dependence and Increasing Returns
- Path Dependent or Tipping Point

### Networks

(expanded, click to collapse)

- Networks
- The Structure of Networks
- The Logic of Network Formation
- Network Function

### Randomness and Random Walks

(expanded, click to collapse)

- Randomness and Random Walk Models
- Sources of Randomness
- Skill and Luck
- Random Walks
- Random Walks and Wall Street
- FInite Memory Random Walks

### Colonel Blotto

(expanded, click to collapse)

- Colonel Blotto Game
- Blotto: No Best Strategy
- Applications of Colonel Blotto
- Blotto: Troop Advantages
- Blotto and Competition

### Prisoners' Dilemma and Collective Action

(expanded, click to collapse)

- Intro: The Prisoners' Dilemma and Collective Action
- The Prisoners' Dilemma Game
- Seven Ways To Cooperation
- Collective Action and Common Pool Resource Problems
- No Panacea

### Mechanism Design

(expanded, click to collapse)

- Mechanism Design
- Hidden Action and Hidden Information
- Auctions
- Public Projects

### Learning Models: Replicator Dynamics

(expanded, click to collapse)

- Replicator Dynamics
- The Replicator Equation
- Fisher's Theorem
- Variation or Six Sigma

### Prediction and the Many Model Thinker

(expanded, click to collapse)

- Prediction
- Linear Models
- Diversity Prediction Theorem
- The Many Model Thinker

Close